@@ -292,7 +292,7 @@ def sanitize_schema(hub, schema: Any) -> Any:
 
 
 def sanitize_key(hub, key: str) -> str:
-    return hub.tool.format.keyword.unclash(hub.tool.gcp.case.snake(key))
+    return hub.tool.gcp.case.unclash(hub.tool.gcp.case.snake(key))
 
 
 def _generate_random_classname() -> str:
