@@ -127,14 +127,6 @@ async def list_(
         result["result"] = False
         return result
 
-    if crypto_keys["ret"].get("items"):
-        result["ret"].extend(crypto_keys["ret"]["items"])
-
-    if not result["ret"]:
-        result["comment"] += (
-            hub.tool.gcp.comment_utils.list_empty_comment(
-                "gcp.cloudkms.crypto_key", key_ring
-            ),
-        )
+    result["ret"] = crypto_keys["ret"].get("items", [])
 
     return result
