@@ -69,7 +69,7 @@ async def list_(
 
     Args:
         crypto_key(str):
-            key ring resource_id.
+            crypto key resource_id.
 
         filter_(str, Optional):
             Only include resources that match the filter in the response. For more information, see
@@ -105,17 +105,7 @@ async def list_(
         result["result"] = False
         return result
 
-    if isinstance(crypto_key_versions["ret"], dict) and crypto_key_versions["ret"].get(
-        "items"
-    ):
-        result["ret"].extend(crypto_key_versions["ret"]["items"])
-
-    if not result["ret"]:
-        result["comment"] += (
-            hub.tool.gcp.comment_utils.list_empty_comment(
-                "gcp.cloudkms.crypto_key_version", crypto_key
-            ),
-        )
+    result["ret"] = crypto_key_versions["ret"].get("items", [])
 
     return result
 
