@@ -100,14 +100,6 @@ async def list_(hub, ctx, project: str = None, filter_: str = None) -> Dict[str,
         result["result"] = False
         return result
 
-    if locations["ret"].get("items"):
-        result["ret"] = locations["ret"]["items"]
-
-    if not result["ret"]:
-        result["comment"] += (
-            hub.tool.gcp.comment_utils.list_empty_comment(
-                "gcp.cloudkms.location", name
-            ),
-        )
+    result["ret"] = locations["ret"].get("items", [])
 
     return result
