@@ -66,11 +66,7 @@ async def list_(
         result["result"] = False
         return result
 
-    items_list = None
-    if list_result and list_result.get("ret"):
-        items_list = list_result["ret"].get("items")
-
-    result["ret"] = items_list
+    result["ret"] = list_result["ret"].get("items", [])
     return result
 
 
