@@ -1,5 +1,4 @@
-"""
-Azure Resource Manager (ARM) Management exceptions module.
+"""Google Cloud Platform provider exceptions module.
 
 Copyright (c) 2021 VMware, Inc. All Rights Reserved.
 SPDX-License-Identifier: Apache-2.0
@@ -8,15 +7,15 @@ from functools import wraps
 
 
 def entry_exit_log(func):
-    """
-    Decorator function to log function/method entry and exits.
+    """Decorator function to log function/method entry and exits.
+
     :param func: The function to decorate.
     """
 
     @wraps(func)
     def wrapper(*args, **kwargs):
-        """
-        Logs any entry and exit to the wrapped func.
+        """Logs any entry and exit to the wrapped func.
+
         :param args: All positional args to func.
         :param kwargs: All keyword args to the func.
         """
