@@ -6,6 +6,9 @@ from typing import Dict
 from typing import List
 
 __contracts__ = ["resource"]
+RESOURCE_TYPE = "cloudkms.crypto_key"
+RESOURCE_TYPE_FULL = "cloudkms.projects.locations.key_rings.crypto_keys"
+GCP_RESOURCE_TYPE_FULL = "gcp.cloudkms.crypto_key"
 
 
 async def present(
@@ -217,6 +220,22 @@ async def present(
         "get_resource_only_with_resource_id", False
     )
 
+    if hub.tool.gcp.resource_prop_utils.properties_mismatch_resource_id(
+        RESOURCE_TYPE_FULL,
+        resource_id,
+        {
+            "project_id": project_id,
+            "location_id": location_id,
+            "key_ring_id": key_ring_id,
+            "crypto_key_id": crypto_key_id,
+        },
+    ):
+        result["comment"].append(
+            hub.tool.gcp.comment_utils.properties_mismatch_resource_id_comment(
+                RESOURCE_TYPE_FULL, name
+            )
+        )
+
     if resource_id:
         old_get_ret = await hub.exec.gcp.cloudkms.crypto_key.get(
             ctx, resource_id=resource_id
@@ -232,7 +251,7 @@ async def present(
         result["old_state"] = old_get_ret["ret"]
     elif not get_resource_only_with_resource_id:
         resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
-            "cloudkms.projects.locations.key_rings.crypto_keys",
+            RESOURCE_TYPE_FULL,
             {
                 "project_id": project_id,
                 "location_id": location_id,
@@ -292,22 +311,24 @@ async def present(
 
         if ctx["test"]:
             if update_mask or update_primary_version:
-                result["new_state"] = {**result["old_state"], **resource_body}
+                result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                    {**result["old_state"], **resource_body}
+                )
                 result["comment"].append(
                     hub.tool.gcp.comment_utils.would_update_comment(
-                        "gcp.cloudkms.crypto_key", resource_id
+                        GCP_RESOURCE_TYPE_FULL, resource_id
                     )
                 )
             else:
                 result["comment"].append(
                     hub.tool.gcp.comment_utils.up_to_date_comment(
-                        "gcp.cloudkms.crypto_key", resource_id
+                        GCP_RESOURCE_TYPE_FULL, resource_id
                     )
                 )
             return result
 
         els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
-            "cloudkms.projects.locations.key_rings.crypto_keys", resource_id
+            RESOURCE_TYPE_FULL, resource_id
         )
         if (
             els.get("project_id") != project_id
@@ -318,7 +339,7 @@ async def present(
             result["result"] = False
             result["comment"].append(
                 hub.tool.gcp.comment_utils.non_updatable_properties_comment(
-                    "gcp.cloudkms.crypto_key",
+                    GCP_RESOURCE_TYPE_FULL,
                     resource_id,
                     ["project_id", "location_id", "key_ring_id", "crypto_key_id"],
                 )
@@ -370,13 +391,13 @@ async def present(
         if update_mask or update_primary_version:
             result["comment"].append(
                 hub.tool.gcp.comment_utils.update_comment(
-                    "gcp.cloudkms.crypto_key", resource_id
+                    GCP_RESOURCE_TYPE_FULL, resource_id
                 )
             )
         else:
             result["comment"].append(
                 hub.tool.gcp.comment_utils.up_to_date_comment(
-                    "gcp.cloudkms.crypto_key", resource_id
+                    GCP_RESOURCE_TYPE_FULL, resource_id
                 )
             )
         return result
@@ -385,18 +406,20 @@ async def present(
         if ctx["test"]:
             result["comment"].append(
                 hub.tool.gcp.comment_utils.would_create_comment(
-                    "gcp.cloudkms.crypto_key", name
+                    GCP_RESOURCE_TYPE_FULL, name
                 )
             )
-            result["new_state"] = {
-                "resource_id": resource_id,
-                "name": name,
-                "project_id": project_id,
-                "location_id": location_id,
-                "key_ring_id": key_ring_id,
-                "crypto_key_id": crypto_key_id,
-                **resource_body,
-            }
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                {
+                    "resource_id": resource_id,
+                    "name": name,
+                    "project_id": project_id,
+                    "location_id": location_id,
+                    "key_ring_id": key_ring_id,
+                    "crypto_key_id": crypto_key_id,
+                    **resource_body,
+                }
+            )
             return result
 
         create_ret = await hub.exec.gcp_api.client.cloudkms.projects.locations.key_rings.crypto_keys.create(
@@ -419,7 +442,7 @@ async def present(
             return result
         result["comment"].append(
             hub.tool.gcp.comment_utils.create_comment(
-                "gcp.cloudkms.crypto_key", resource_id
+                GCP_RESOURCE_TYPE_FULL, resource_id
             )
         )
         result["new_state"] = {
@@ -456,7 +479,7 @@ async def absent(hub, ctx, name: str) -> Dict[str, Any]:
         "result": False,
         "comment": [
             hub.tool.gcp.comment_utils.no_resource_delete_comment(
-                "gcp.cloudkms.crypto_key"
+                GCP_RESOURCE_TYPE_FULL
             )
         ],
         "old_state": None,
@@ -515,7 +538,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
                             ]
                         }
                         els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
-                            "cloudkms.projects.locations.key_rings.crypto_keys",
+                            RESOURCE_TYPE_FULL,
                             resource_id,
                         )
                         p = result[resource_id]["gcp.cloudkms.crypto_key.present"]
