@@ -5,6 +5,11 @@ from typing import Any
 from typing import Dict
 
 __contracts__ = ["resource"]
+RESOURCE_TYPE = "cloudkms.crypto_key_versions"
+RESOURCE_TYPE_FULL = (
+    "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions"
+)
+GCP_RESOURCE_TYPE_FULL = "gcp.cloudkms.crypto_key_versions"
 
 
 async def present(
@@ -130,6 +135,23 @@ async def present(
     get_resource_only_with_resource_id = hub.OPT.idem.get(
         "get_resource_only_with_resource_id", False
     )
+
+    if hub.tool.gcp.resource_prop_utils.properties_mismatch_resource_id(
+        RESOURCE_TYPE_FULL,
+        resource_id,
+        {
+            "project_id": project_id,
+            "location_id": location_id,
+            "key_ring_id": key_ring_id,
+            "crypto_key_id": crypto_key_id,
+            "crypto_key_version_id": crypto_key_version_id,
+        },
+    ):
+        result["comment"].append(
+            hub.tool.gcp.comment_utils.properties_mismatch_resource_id_comment(
+                RESOURCE_TYPE_FULL, name
+            )
+        )
     if resource_id:
         old_get_ret = await hub.exec.gcp.cloudkms.crypto_key_version.get(
             ctx, resource_id=resource_id
@@ -143,7 +165,7 @@ async def present(
             return result
 
         els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
-            "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
+            RESOURCE_TYPE_FULL,
             resource_id,
         )
         if (
@@ -187,7 +209,7 @@ async def present(
         if project_id and location_id and key_ring_id and crypto_key_id:
             if crypto_key_version_id:
                 resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
-                    "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
+                    RESOURCE_TYPE_FULL,
                     {
                         "project_id": project_id,
                         "location_id": location_id,
@@ -242,7 +264,7 @@ async def present(
 
     if ctx["test"]:
         resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
-            "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
+            RESOURCE_TYPE_FULL,
             {
                 "project_id": project_id,
                 "location_id": location_id,
@@ -267,24 +289,28 @@ async def present(
                     "gcp.cloudkms.crypto_key_version", resource_id
                 )
             )
-            result["new_state"] = {
-                "resource_id": resource_id,
-                "name": name,
-                "project_id": project_id,
-                "location_id": location_id,
-                "key_ring_id": key_ring_id,
-                "crypto_key_id": crypto_key_id,
-                "crypto_key_version_id": crypto_key_version_id,
-                **resource_body,
-            }
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                {
+                    "resource_id": resource_id,
+                    "name": name,
+                    "project_id": project_id,
+                    "location_id": location_id,
+                    "key_ring_id": key_ring_id,
+                    "crypto_key_id": crypto_key_id,
+                    "crypto_key_version_id": crypto_key_version_id,
+                    **resource_body,
+                }
+            )
         else:
-            result["new_state"] = {
-                **result["old_state"],
-                **{
-                    "key_state" if k == "state" else k: v
-                    for k, v in resource_body.items()
-                },
-            }
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                {
+                    **result["old_state"],
+                    **{
+                        "key_state" if k == "state" else k: v
+                        for k, v in resource_body.items()
+                    },
+                }
+            )
             update_mask = hub.tool.gcp.cloudkms.patch.calc_update_mask(
                 resource_body,
                 {
@@ -522,7 +548,7 @@ async def absent(
     if not resource_id and not get_resource_only_with_resource_id:
         resource_id = (
             hub.tool.gcp.resource_prop_utils.construct_resource_id(
-                "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
+                RESOURCE_TYPE_FULL,
                 {
                     "project_id": project_id,
                     "location_id": location_id,
@@ -652,7 +678,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
                                     ]
                                 }
                                 els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
-                                    "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
+                                    RESOURCE_TYPE_FULL,
                                     resource_id,
                                 )
                                 p = result[resource_id][
