@@ -3,6 +3,9 @@ from typing import Any
 from typing import Dict
 
 __contracts__ = ["resource"]
+RESOURCE_TYPE = "cloudkms.key_ring"
+RESOURCE_TYPE_FULL = "cloudkms.projects.locations.key_rings"
+GCP_RESOURCE_TYPE_FULL = "gcp.cloudkms.key_ring"
 
 
 async def present(
@@ -54,6 +57,21 @@ async def present(
         "comment": [],
     }
 
+    if hub.tool.gcp.resource_prop_utils.properties_mismatch_resource_id(
+        RESOURCE_TYPE_FULL,
+        resource_id,
+        {
+            "project_id": project_id,
+            "location_id": location_id,
+            "key_ring_id": key_ring_id,
+        },
+    ):
+        result["comment"].append(
+            hub.tool.gcp.comment_utils.properties_mismatch_resource_id_comment(
+                RESOURCE_TYPE_FULL, name
+            )
+        )
+
     get_resource_only_with_resource_id = hub.OPT.idem.get(
         "get_resource_only_with_resource_id", False
     )
@@ -72,7 +90,7 @@ async def present(
         result["old_state"] = old_get_ret["ret"]
     elif not get_resource_only_with_resource_id:
         resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
-            "cloudkms.projects.locations.key_rings",
+            RESOURCE_TYPE_FULL,
             {
                 "project_id": project_id,
                 "location_id": location_id,
@@ -95,7 +113,7 @@ async def present(
         resource_id = result["old_state"].get("resource_id", None)
 
         els = hub.tool.gcp.resource_prop_utils.get_elements_from_resource_id(
-            "cloudkms.projects.locations.key_rings", resource_id
+            RESOURCE_TYPE_FULL, resource_id
         )
         if (
             els.get("project_id") != project_id
@@ -128,7 +146,7 @@ async def present(
                 "gcp.cloudkms.key_ring", key_ring_id
             )
         )
-        result["new_state"] = plan_state
+        result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(plan_state)
         return result
 
     create_ret = (
