@@ -352,7 +352,7 @@ async def present(
     project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
 
     if ctx.get("wrapper_result"):
-        result["old_state"] = ctx.get("wrapper_result").get("old_state", None)
+        result = ctx.get("wrapper_result")
 
     # to be autogenerated by pop-create based on insert/update props in properties.yaml
     resource_body = {
@@ -385,238 +385,285 @@ async def present(
         "id_": id_,
     }
 
-    # TODO: How to handle query params which are not returned in the response body of get
-    plan_state = {"resource_id": resource_id, **resource_body}
-
-    plan_state = {k: v for (k, v) in plan_state.items() if v is not None}
+    resource_body = {k: v for (k, v) in resource_body.items() if v is not None}
     operation = None
     if result["old_state"]:
+        # Update
         resource_id = result["old_state"].get("resource_id", None)
         zone = hub.tool.gcp.resource_prop_utils.parse_link_to_zone(
             result["old_state"]["zone"]
         )
         result["old_state"]["zone"] = zone
-        # Resize
-        size_gb_updated = False
-        if size_gb is not None and str(result["old_state"]["size_gb"]) != str(size_gb):
-            if not ctx.get("test"):
-                resize_body = {"size_gb": size_gb}
-                update_ret = await hub.exec.gcp_api.client.compute.disk.resize(
-                    ctx,
-                    resource_id=resource_id,
-                    body=resize_body,
-                    request_id=request_id,
+
+        changes = hub.tool.gcp.utils.compare_states(
+            result["old_state"],
+            {
+                "resource_id": resource_id,
+                **resource_body,
+            },
+            "compute.disk",
+        )
+
+        resource_updated = False
+        if changes:
+            changed_non_updatable_properties = (
+                hub.tool.gcp.resource_prop_utils.get_changed_non_updatable_properties(
+                    "compute.disk", changes
                 )
-
-                if not update_ret["result"]:
-                    result["result"] = False
-                    result["comment"] += update_ret["comment"]
-                    return result
-
-                if hub.tool.gcp.operation_utils.is_operation(update_ret["ret"]):
-                    operation = update_ret["ret"]
-                    operation_type = hub.tool.gcp.operation_utils.get_operation_type(
-                        operation.get("selfLink")
+            )
+            if changed_non_updatable_properties:
+                result["result"] = False
+                result["comment"].append(
+                    hub.tool.gcp.comment_utils.non_updatable_properties_comment(
+                        "gcp.compute.disk",
+                        name,
+                        changed_non_updatable_properties,
                     )
-                    operation_id = (
-                        hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                            operation.get("selfLink"), operation_type
-                        )
-                    )
-                    handle_operation_ret = (
-                        await hub.tool.gcp.operation_utils.handle_operation(
-                            ctx, {"operation_id": operation_id}, "compute.disk", True
-                        )
-                    )
-                    if not handle_operation_ret["result"]:
-                        result["comment"] += handle_operation_ret["comment"]
-                        return result
-
-            size_gb_updated = True
-
-        # Update labels
-        labels_updated = False
-        if (
-            labels is not None
-            and not (labels == {} and result["old_state"].get("labels") is None)
-            and result["old_state"].get("labels") != labels
-        ):
-            if not ctx.get("test"):
-                set_labels_body = {
-                    "labels": labels,
-                    "label_fingerprint": label_fingerprint,
-                }
-                kwargs = {
-                    "project": project,
-                    "resource": name,
-                    "body": set_labels_body,
-                    "request_id": request_id,
-                }
-                if zone:
-                    kwargs.update({"zone": zone})
-                if region:
-                    kwargs.update({"region": region})
-
-                update_ret = await hub.exec.gcp_api.client.compute.disk.setLabels(
-                    ctx,
-                    **kwargs,
                 )
+                result["new_state"] = result["old_state"]
+                return result
 
-                if not update_ret["result"]:
-                    result["result"] = False
-                    result["comment"] += update_ret["comment"]
-                    return result
-
-                if hub.tool.gcp.operation_utils.is_operation(update_ret["ret"]):
-                    operation = update_ret["ret"]
-                    operation_type = hub.tool.gcp.operation_utils.get_operation_type(
-                        operation.get("selfLink")
-                    )
-                    operation_id = (
-                        hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                            operation.get("selfLink"), operation_type
-                        )
-                    )
-                    handle_operation_ret = (
-                        await hub.tool.gcp.operation_utils.handle_operation(
-                            ctx, {"operation_id": operation_id}, "compute.disk", True
-                        )
-                    )
-                    if not handle_operation_ret["result"]:
-                        result["comment"] += handle_operation_ret["comment"]
-                        return result
-
-            labels_updated = True
-
-        # Update resource policies
-        resource_policies_updated = False
-        if not hub.tool.gcp.state_comparison_utils.are_lists_identical(
-            result["old_state"].get("resource_policies"), resource_policies
-        ):
-            # If (some) resource policies are links, parse them to resource policy resource ids
-            new_resource_policies = [
-                hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                    policy, "compute.resource_policy"
-                )
-                for policy in (
-                    resource_policies if resource_policies is not None else []
-                )
-            ]
-            current_resource_policies = [
-                hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
-                    policy, "compute.resource_policy"
-                )
-                for policy in result["old_state"].get("resource_policies", [])
-            ]
-
-            resource_policies_to_remove = [
-                policy
-                for policy in current_resource_policies
-                if policy not in new_resource_policies
-            ]
-            resource_policies_to_add = [
-                policy
-                for policy in new_resource_policies
-                if policy not in current_resource_policies
-            ]
-
-            if (
-                len(resource_policies_to_remove) > 0
-                or len(resource_policies_to_add) > 0
+            # Resize
+            size_gb_updated = False
+            if size_gb is not None and str(result["old_state"]["size_gb"]) != str(
+                size_gb
             ):
                 if not ctx.get("test"):
-                    add_request_body = None
-                    if len(resource_policies_to_add) > 0:
-                        add_request_body = {
-                            "resource_policies": resource_policies_to_add
-                        }
-                    remove_request_body = None
-                    if len(resource_policies_to_remove) > 0:
-                        remove_request_body = {
-                            "resource_policies": resource_policies_to_remove
-                        }
+                    resize_body = {"size_gb": size_gb}
+                    update_ret = await hub.exec.gcp_api.client.compute.disk.resize(
+                        ctx,
+                        resource_id=resource_id,
+                        body=resize_body,
+                        request_id=request_id,
+                    )
 
-                    remove_ret = None
-                    if remove_request_body is not None:
-                        remove_ret = await hub.exec.gcp_api.client.compute.disk.removeResourcePolicies(
-                            ctx,
-                            resource_id=resource_id,
-                            body=remove_request_body,
-                            request_id=request_id,
-                        )
+                    if not update_ret["result"]:
+                        result["result"] = False
+                        result["comment"] += update_ret["comment"]
+                        return result
 
-                        if not remove_ret["result"]:
-                            result["result"] = False
-                            result["comment"] += remove_ret["comment"]
-                            return result
-
-                        if hub.tool.gcp.operation_utils.is_operation(remove_ret["ret"]):
-                            operation = remove_ret["ret"]
-                            operation_type = (
-                                hub.tool.gcp.operation_utils.get_operation_type(
-                                    operation.get("selfLink")
-                                )
+                    if hub.tool.gcp.operation_utils.is_operation(update_ret["ret"]):
+                        operation = update_ret["ret"]
+                        operation_type = (
+                            hub.tool.gcp.operation_utils.get_operation_type(
+                                operation.get("selfLink")
                             )
-                            operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
+                        )
+                        operation_id = (
+                            hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
                                 operation.get("selfLink"), operation_type
                             )
-                            handle_operation_ret = (
-                                await hub.tool.gcp.operation_utils.handle_operation(
-                                    ctx,
-                                    {"operation_id": operation_id},
-                                    "compute.disk",
-                                    True,
-                                )
-                            )
-                            if not handle_operation_ret["result"]:
-                                result["comment"] += handle_operation_ret["comment"]
-                                return result
-
-                    if (
-                        remove_ret is None or remove_ret["result"]
-                    ) and add_request_body is not None:
-                        add_ret = await hub.exec.gcp_api.client.compute.disk.addResourcePolicies(
-                            ctx,
-                            resource_id=resource_id,
-                            body=add_request_body,
-                            request_id=request_id,
                         )
-
-                        if not add_ret["result"]:
+                        handle_operation_ret = (
+                            await hub.tool.gcp.operation_utils.handle_operation(
+                                ctx,
+                                {"operation_id": operation_id},
+                                "compute.disk",
+                                True,
+                            )
+                        )
+                        if not handle_operation_ret["result"]:
                             result["result"] = False
-                            result["comment"] += add_ret["comment"]
+                            result["comment"] += handle_operation_ret["comment"]
                             return result
 
-                        if hub.tool.gcp.operation_utils.is_operation(add_ret["ret"]):
-                            operation = add_ret["ret"]
-                            operation_type = (
-                                hub.tool.gcp.operation_utils.get_operation_type(
-                                    operation.get("selfLink")
-                                )
+                size_gb_updated = True
+
+            # Update labels
+            labels_updated = False
+            if (
+                labels is not None
+                and not (labels == {} and result["old_state"].get("labels") is None)
+                and result["old_state"].get("labels") != labels
+            ):
+                if not ctx.get("test"):
+                    set_labels_body = {
+                        "labels": labels,
+                        "label_fingerprint": label_fingerprint,
+                    }
+                    kwargs = {
+                        "project": project,
+                        "resource": name,
+                        "body": set_labels_body,
+                        "request_id": request_id,
+                    }
+                    if zone:
+                        kwargs.update({"zone": zone})
+                    if region:
+                        kwargs.update({"region": region})
+
+                    update_ret = await hub.exec.gcp_api.client.compute.disk.setLabels(
+                        ctx,
+                        **kwargs,
+                    )
+
+                    if not update_ret["result"]:
+                        result["result"] = False
+                        result["comment"] += update_ret["comment"]
+                        return result
+
+                    if hub.tool.gcp.operation_utils.is_operation(update_ret["ret"]):
+                        operation = update_ret["ret"]
+                        operation_type = (
+                            hub.tool.gcp.operation_utils.get_operation_type(
+                                operation.get("selfLink")
                             )
-                            operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
+                        )
+                        operation_id = (
+                            hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
                                 operation.get("selfLink"), operation_type
                             )
-                            handle_operation_ret = (
-                                await hub.tool.gcp.operation_utils.handle_operation(
-                                    ctx,
-                                    {"operation_id": operation_id},
-                                    "compute.disk",
-                                    True,
-                                )
+                        )
+                        handle_operation_ret = (
+                            await hub.tool.gcp.operation_utils.handle_operation(
+                                ctx,
+                                {"operation_id": operation_id},
+                                "compute.disk",
+                                True,
                             )
-                            if not handle_operation_ret["result"]:
-                                result["comment"] += handle_operation_ret["comment"]
+                        )
+                        if not handle_operation_ret["result"]:
+                            result["result"] = False
+                            result["comment"] += handle_operation_ret["comment"]
+                            return result
+
+                labels_updated = True
+
+            # Update resource policies
+            resource_policies_updated = False
+            if not hub.tool.gcp.state_comparison_utils.are_lists_identical(
+                result["old_state"].get("resource_policies"), resource_policies
+            ):
+                # If (some) resource policies are links, parse them to resource policy resource ids
+                new_resource_policies = [
+                    hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
+                        policy, "compute.resource_policy"
+                    )
+                    for policy in (
+                        resource_policies if resource_policies is not None else []
+                    )
+                ]
+                current_resource_policies = [
+                    hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
+                        policy, "compute.resource_policy"
+                    )
+                    for policy in result["old_state"].get("resource_policies", [])
+                ]
+
+                resource_policies_to_remove = [
+                    policy
+                    for policy in current_resource_policies
+                    if policy not in new_resource_policies
+                ]
+                resource_policies_to_add = [
+                    policy
+                    for policy in new_resource_policies
+                    if policy not in current_resource_policies
+                ]
+
+                if (
+                    len(resource_policies_to_remove) > 0
+                    or len(resource_policies_to_add) > 0
+                ):
+                    if not ctx.get("test"):
+                        add_request_body = None
+                        if len(resource_policies_to_add) > 0:
+                            add_request_body = {
+                                "resource_policies": resource_policies_to_add
+                            }
+                        remove_request_body = None
+                        if len(resource_policies_to_remove) > 0:
+                            remove_request_body = {
+                                "resource_policies": resource_policies_to_remove
+                            }
+
+                        remove_ret = None
+                        if remove_request_body is not None:
+                            remove_ret = await hub.exec.gcp_api.client.compute.disk.removeResourcePolicies(
+                                ctx,
+                                resource_id=resource_id,
+                                body=remove_request_body,
+                                request_id=request_id,
+                            )
+
+                            if not remove_ret["result"]:
+                                result["result"] = False
+                                result["comment"] += remove_ret["comment"]
                                 return result
 
-                resource_policies_updated = True
+                            if hub.tool.gcp.operation_utils.is_operation(
+                                remove_ret["ret"]
+                            ):
+                                operation = remove_ret["ret"]
+                                operation_type = (
+                                    hub.tool.gcp.operation_utils.get_operation_type(
+                                        operation.get("selfLink")
+                                    )
+                                )
+                                operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
+                                    operation.get("selfLink"), operation_type
+                                )
+                                handle_operation_ret = (
+                                    await hub.tool.gcp.operation_utils.handle_operation(
+                                        ctx,
+                                        {"operation_id": operation_id},
+                                        "compute.disk",
+                                        True,
+                                    )
+                                )
+                                if not handle_operation_ret["result"]:
+                                    result["result"] = False
+                                    result["comment"] += handle_operation_ret["comment"]
+                                    return result
+
+                        if (
+                            remove_ret is None or remove_ret["result"]
+                        ) and add_request_body is not None:
+                            add_ret = await hub.exec.gcp_api.client.compute.disk.addResourcePolicies(
+                                ctx,
+                                resource_id=resource_id,
+                                body=add_request_body,
+                                request_id=request_id,
+                            )
+
+                            if not add_ret["result"]:
+                                result["result"] = False
+                                result["comment"] += add_ret["comment"]
+                                return result
+
+                            if hub.tool.gcp.operation_utils.is_operation(
+                                add_ret["ret"]
+                            ):
+                                operation = add_ret["ret"]
+                                operation_type = (
+                                    hub.tool.gcp.operation_utils.get_operation_type(
+                                        operation.get("selfLink")
+                                    )
+                                )
+                                operation_id = hub.tool.gcp.resource_prop_utils.parse_link_to_resource_id(
+                                    operation.get("selfLink"), operation_type
+                                )
+                                handle_operation_ret = (
+                                    await hub.tool.gcp.operation_utils.handle_operation(
+                                        ctx,
+                                        {"operation_id": operation_id},
+                                        "compute.disk",
+                                        True,
+                                    )
+                                )
+                                if not handle_operation_ret["result"]:
+                                    result["comment"] += handle_operation_ret["comment"]
+                                    return result
+
+                    resource_policies_updated = True
+
+            resource_updated = (
+                size_gb_updated or labels_updated or resource_policies_updated
+            )
 
         # Reset the operation because we don't need it
         # since we are waiting for the operations to finish in order to proceed
         operation = None
-        resource_updated = (
-            size_gb_updated or labels_updated or resource_policies_updated
-        )
         if resource_updated:
             if ctx.get("test", False):
                 result["comment"].append(
@@ -624,7 +671,13 @@ async def present(
                         "gcp.compute.disk", name
                     )
                 )
-                result["new_state"] = {**result["old_state"], **plan_state}
+                result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                    {
+                        "resource_id": resource_id,
+                        **result["old_state"],
+                        **resource_body,
+                    }
+                )
                 result["new_state"]["resource_id"] = resource_id
             else:
                 get_ret = await hub.exec.gcp.compute.disk.get(
@@ -652,7 +705,9 @@ async def present(
                     "gcp.compute.disk", name
                 )
             )
-            result["new_state"] = plan_state
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                {"resource_id": resource_id, **resource_body}
+            )
             result["new_state"]["resource_id"] = resource_id
             return result
 
