@@ -16,6 +16,8 @@ from idem_gcp.tool.gcp.utils import global_absent
 absent = global_absent
 
 __contracts__ = ["resource"]
+RESOURCE_TYPE = "compute.firewall"
+RESOURCE_TYPE_FULL = "gcp.compute.firewall"
 
 
 async def present(
@@ -181,10 +183,20 @@ async def present(
     }
 
     project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
+    resource_type_camel = hub.tool.gcp.case.camel(RESOURCE_TYPE_FULL.split(".")[-1])
+
+    if hub.tool.gcp.resource_prop_utils.properties_mismatch_resource_id(
+        RESOURCE_TYPE, resource_id, {**locals(), resource_type_camel: name}
+    ):
+        result["comment"].append(
+            hub.tool.gcp.comment_utils.properties_mismatch_resource_id_comment(
+                RESOURCE_TYPE_FULL, name
+            )
+        )
 
     if ctx.get("rerun_data"):
         handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
-            ctx, ctx.get("rerun_data"), "compute.firewall"
+            ctx, ctx.get("rerun_data"), RESOURCE_TYPE
         )
 
         if not handle_operation_ret["result"]:
@@ -221,22 +233,18 @@ async def present(
             result["old_state"] = ctx["rerun_data"]["old_state"]
             if ctx["rerun_data"]["old_state"]:
                 result["comment"].append(
-                    hub.tool.gcp.comment_utils.update_comment(
-                        "gcp.compute.firewall", name
-                    )
+                    hub.tool.gcp.comment_utils.update_comment(RESOURCE_TYPE_FULL, name)
                 )
             else:
                 result["comment"].append(
-                    hub.tool.gcp.comment_utils.create_comment(
-                        "gcp.compute.firewall", name
-                    )
+                    hub.tool.gcp.comment_utils.create_comment(RESOURCE_TYPE_FULL, name)
                 )
             return result
 
         result["old_state"] = old_get_ret["ret"]
     elif not get_resource_only_with_resource_id:
         resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
-            "compute.firewall", {"project": project, "firewall": name}
+            RESOURCE_TYPE, {"project": project, "firewall": name}
         )
         old_get_ret = await hub.exec.gcp.compute.firewall.get(
             ctx, resource_id=resource_id
@@ -272,14 +280,12 @@ async def present(
     operation = None
     if result["old_state"]:
         changes = hub.tool.gcp.utils.compare_states(
-            result["old_state"], resource_body, "compute.firewall"
+            result["old_state"], resource_body, RESOURCE_TYPE
         )
         if not changes:
             result["result"] = True
             result["comment"].append(
-                hub.tool.gcp.comment_utils.up_to_date_comment(
-                    "gcp.compute.firewall", name
-                )
+                hub.tool.gcp.comment_utils.up_to_date_comment(RESOURCE_TYPE_FULL, name)
             )
             result["new_state"] = result["old_state"]
             return result
@@ -287,10 +293,12 @@ async def present(
         if ctx["test"]:
             result["comment"].append(
                 hub.tool.gcp.comment_utils.would_update_comment(
-                    "gcp.compute.firewall", name
+                    RESOURCE_TYPE_FULL, name
                 )
             )
-            result["new_state"] = {"resource_id": resource_id, **resource_body}
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                {"resource_id": resource_id, **resource_body}
+            )
             return result
 
         update_ret = await hub.exec.gcp_api.client.compute.firewall.patch(
@@ -312,17 +320,19 @@ async def present(
 
         result["new_state"] = get_ret["ret"]
         result["comment"].append(
-            hub.tool.gcp.comment_utils.update_comment("gcp.compute.firewall", name)
+            hub.tool.gcp.comment_utils.update_comment(RESOURCE_TYPE_FULL, name)
         )
         return result
     else:
         if ctx.get("test", False):
             result["comment"].append(
                 hub.tool.gcp.comment_utils.would_create_comment(
-                    "gcp.compute.firewall", name
+                    RESOURCE_TYPE_FULL, name
                 )
             )
-            result["new_state"] = {"resource_id": resource_id, **resource_body}
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                {"resource_id": resource_id, **resource_body}
+            )
             return result
         create_ret = await hub.exec.gcp_api.client.compute.firewall.insert(
             ctx, project=project, body=resource_body
@@ -339,7 +349,7 @@ async def present(
             ):
                 result["comment"].append(
                     hub.tool.gcp.comment_utils.already_exists_comment(
-                        "gcp.compute.firewall", name
+                        RESOURCE_TYPE_FULL, name
                     )
                 )
             else:
