@@ -1137,7 +1137,7 @@ async def present(
     project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
 
     if ctx.get("wrapper_result"):
-        result["old_state"] = ctx.get("wrapper_result").get("old_state", None)
+        result = ctx.get("wrapper_result")
 
     # to be autogenerated by pop-create based on insert/update props in properties.yaml
     resource_body = {
@@ -1273,7 +1273,9 @@ async def present(
                     "gcp.compute.instance", name
                 )
             )
-            result["new_state"] = resource_body
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                resource_body
+            )
             result["new_state"]["resource_id"] = resource_id
             return result
 
@@ -1350,7 +1352,9 @@ async def present(
                     "gcp.compute.instance", name
                 )
             )
-            result["new_state"] = resource_body
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                resource_body
+            )
             result["new_state"]["resource_id"] = resource_id
             return result
 
