@@ -13,6 +13,8 @@ from idem_gcp.tool.gcp.utils import global_absent
 absent = global_absent
 
 __contracts__ = ["resource"]
+RESOURCE_TYPE = "compute.network"
+RESOURCE_TYPE_FULL = "gcp.compute.network"
 
 
 async def present(
@@ -149,6 +151,16 @@ async def present(
     }
 
     project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
+    resource_type_camel = hub.tool.gcp.case.camel(RESOURCE_TYPE_FULL.split(".")[-1])
+
+    if hub.tool.gcp.resource_prop_utils.properties_mismatch_resource_id(
+        RESOURCE_TYPE, resource_id, {**locals(), resource_type_camel: name}
+    ):
+        result["comment"].append(
+            hub.tool.gcp.comment_utils.properties_mismatch_resource_id_comment(
+                RESOURCE_TYPE_FULL, name
+            )
+        )
 
     if ctx.get("rerun_data"):
         handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
@@ -324,7 +336,9 @@ async def present(
                     "gcp.compute.network", name
                 )
             )
-            result["new_state"] = {"resource_id": resource_id, **request_body}
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                {"resource_id": resource_id, **request_body}
+            )
             return result
 
         if peerings_changes:
@@ -378,7 +392,9 @@ async def present(
                     "gcp.compute.network", name
                 )
             )
-            result["new_state"] = {"resource_id": resource_id, **request_body}
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                {"resource_id": resource_id, **request_body}
+            )
             return result
 
         create_ret = await hub.exec.gcp_api.client.compute.network.insert(
@@ -414,7 +430,6 @@ async def present(
             "operation_id": operation_id,
             "old_state": result["old_state"],
         }
-        result["result"] = False
 
     return result
 
@@ -446,7 +461,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         )
         return {}
 
-    for resource in describe_ret["ret"]["items"]:
+    for resource in describe_ret["ret"].get("items", []):
         resource_id = resource.get("resource_id")
 
         result[resource_id] = {
