@@ -152,7 +152,7 @@ async def describe(hub, ctx) -> Dict[str, Dict[str, Any]]:
         )
         return {}
 
-    for resource in describe_ret["ret"]["items"]:
+    for resource in describe_ret["ret"].get("items", []):
         resource_id = resource.get("resource_id")
 
         result[resource_id] = {
