@@ -183,7 +183,8 @@ async def present(
     project = hub.tool.gcp.utils.get_project_from_account(ctx, project)
 
     if ctx.get("wrapper_result"):
-        result["old_state"] = ctx.get("wrapper_result").get("old_state", None)
+        result = ctx.get("wrapper_result")
+
     request_body = {
         "log_config": log_config,
         "purpose": purpose,
@@ -246,7 +247,9 @@ async def present(
                     "gcp.compute.subnetwork", name
                 )
             )
-            result["new_state"] = plan_state
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                plan_state
+            )
             return result
 
         state_operations_ret = await state_operations.run_operations()
@@ -315,7 +318,9 @@ async def present(
                     "gcp.compute.subnetwork", name
                 )
             )
-            result["new_state"] = plan_state
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                plan_state
+            )
             result["new_state"][
                 "resource_id"
             ] = hub.tool.gcp.resource_prop_utils.construct_resource_id(
