@@ -5,6 +5,8 @@ from typing import Dict
 
 
 __contracts__ = ["resource"]
+RESOURCE_TYPE = "iam.projects.service_account"
+RESOURCE_TYPE_FULL = "gcp.iam.projects.service_account"
 
 
 async def present(
@@ -58,6 +60,17 @@ async def present(
         "comment": [],
     }
 
+    resource_type_camel = hub.tool.gcp.case.camel(RESOURCE_TYPE_FULL.split(".")[-1])
+
+    if hub.tool.gcp.resource_prop_utils.properties_mismatch_resource_id(
+        RESOURCE_TYPE, resource_id, {**locals(), resource_type_camel: name}
+    ):
+        result["comment"].append(
+            hub.tool.gcp.comment_utils.properties_mismatch_resource_id_comment(
+                RESOURCE_TYPE_FULL, name
+            )
+        )
+
     # Wait until resource is available in GCP
     if ctx.get("rerun_data"):
         service_account = ctx.get("rerun_data").get("old_state")
@@ -124,19 +137,21 @@ async def present(
         if ctx["test"]:
             result["comment"].append(
                 hub.tool.gcp.comment_utils.would_create_comment(
-                    "gcp.iam.projects.service_account", resource_id
+                    RESOURCE_TYPE_FULL, resource_id
                 )
             )
-            result["new_state"] = {
-                "resource_id": resource_id,
-                "name": name,
-                "project_id": project_id,
-                "unique_id": unique_id,
-                "email": email,
-                "display_name": display_name,
-                "etag": etag,
-                "oauth2_client_id": oauth2_client_id,
-            }
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                {
+                    "resource_id": resource_id,
+                    "name": name,
+                    "project_id": project_id,
+                    "unique_id": unique_id,
+                    "email": email,
+                    "display_name": display_name,
+                    "etag": etag,
+                    "oauth2_client_id": oauth2_client_id,
+                }
+            )
             return result
 
         # Create
@@ -162,7 +177,7 @@ async def present(
 
         result["comment"].append(
             hub.tool.gcp.comment_utils.create_comment(
-                "gcp.iam.projects.service_account", create_ret["ret"]["resource_id"]
+                RESOURCE_TYPE_FULL, create_ret["ret"]["resource_id"]
             )
         )
 
@@ -233,9 +248,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
     if not resource_id:
         # we don't have enough information to know what to delete
         result["comment"].append(
-            hub.tool.gcp.comment_utils.already_absent_comment(
-                "gcp.iam.projects.service_account", name
-            )
+            hub.tool.gcp.comment_utils.already_absent_comment(RESOURCE_TYPE_FULL, name)
         )
         return result
 
@@ -247,7 +260,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
         result["result"] = False
         result["comment"].append(
             hub.tool.gcp.comment_utils.resource_not_found_comment(
-                "gcp.iam.projects.service_account", resource_id
+                RESOURCE_TYPE_FULL, resource_id
             )
         )
         result["comment"].extend(get_ret["comment"])
@@ -255,9 +268,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
     if not get_ret["ret"]:
         result["comment"].append(
-            hub.tool.gcp.comment_utils.already_absent_comment(
-                "gcp.iam.projects.service_account", name
-            )
+            hub.tool.gcp.comment_utils.already_absent_comment(RESOURCE_TYPE_FULL, name)
         )
         return result
 
@@ -265,9 +276,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
 
     if ctx["test"]:
         result["comment"].append(
-            hub.tool.gcp.comment_utils.would_delete_comment(
-                "gcp.iam.projects.service_account", name
-            )
+            hub.tool.gcp.comment_utils.would_delete_comment(RESOURCE_TYPE_FULL, name)
         )
         return result
 
@@ -281,9 +290,7 @@ async def absent(hub, ctx, name: str, resource_id: str = None) -> Dict[str, Any]
         return result
 
     result["comment"].append(
-        hub.tool.gcp.comment_utils.delete_comment(
-            "gcp.iam.projects.service_account", name
-        )
+        hub.tool.gcp.comment_utils.delete_comment(RESOURCE_TYPE_FULL, name)
     )
 
     return result
