@@ -1,12 +1,12 @@
+import copy
+
 LIST_RESOURCES_WITH_PRESENT_WRAPPER = [
     "gcp.compute.instance",
     "gcp.compute.disk",
     "gcp.compute.forwarding_rule",
     "gcp.compute.subnetwork",
-    "gcp.compute.reservation",
     "gcp.compute.backend_service",
     "gcp.compute.machine_image",
-    "gcp.compute.image",
     "gcp.compute.instance_group",
     "gcp.compute.snapshot",
 ]
@@ -67,10 +67,22 @@ async def call_present(hub, ctx):
         or (state_ctx.get("old_state") or {}).get("resource_id")
         or (state_ctx.get("rerun_data") or {}).get("resource_id")
     )
+    local_params = {**ctx.kwargs}
+    local_params.update({resource_type_camel: name})
 
     get_resource_only_with_resource_id = hub.OPT.idem.get(
         "get_resource_only_with_resource_id", False
     )
+
+    if hub.tool.gcp.resource_prop_utils.properties_mismatch_resource_id(
+        service_resource_type, resource_id, local_params
+    ):
+        result["comment"].append(
+            hub.tool.gcp.comment_utils.properties_mismatch_resource_id_comment(
+                gcp_service_resource_type, name
+            )
+        )
+
     if state_ctx.get("rerun_data"):
         handle_operation_ret = await hub.tool.gcp.operation_utils.handle_operation(
             state_ctx,
@@ -118,12 +130,22 @@ async def call_present(hub, ctx):
                         gcp_service_resource_type, name
                     )
                 )
+
+            ctx_kwargs = {k: v for (k, v) in ctx.kwargs.items() if v is not None}
+            diff = hub.tool.gcp.utils.compare_states(
+                result["new_state"], ctx_kwargs, service_resource_type
+            )
+            values_mismatch: set = diff.get("relevant_changes")
+            if values_mismatch:
+                values_mismatch.discard("root['ctx']")
+                if values_mismatch:
+                    result["comment"].append(
+                        f"Values mismatch between actual and desired states: {values_mismatch}"
+                    )
             return result
 
         result["old_state"] = old_get_ret["ret"]
     elif not get_resource_only_with_resource_id:
-        local_params = {**ctx.kwargs}
-        local_params.update({resource_type_camel: name})
         resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
             service_resource_type, local_params
         )
@@ -149,6 +171,25 @@ async def call_present(hub, ctx):
     return await ctx.func(*ctx.args, **{**ctx.kwargs, "resource_id": resource_id})
 
 
+async def post_present(hub, ctx):
+    if ctx.ret and "old_state" in ctx.ret and "new_state" in ctx.ret:
+        old_state = ctx.ret.get("old_state")
+        new_state = ctx.ret.get("new_state")
+
+        state_ctx = ctx.kwargs.get("ctx")
+        resource_state_path = state_ctx.get("tag").split("_|")[0]
+        service_resource_type = (
+            hub.tool.gcp.resource_prop_utils.get_service_resource_type(
+                resource_state_path
+            )
+        )
+
+        changes = hub.tool.gcp.utils.compare_changes(
+            copy.deepcopy(old_state), copy.deepcopy(new_state), service_resource_type
+        )
+        ctx.ret["changes"] = changes
+
+
 async def call_absent(hub, ctx):
     state_ctx = ctx.kwargs.get("ctx")
     assert state_ctx, f"state context is missing: {state_ctx}"
