@@ -322,6 +322,16 @@ async def present(
         "comment": [],
     }
 
+    resource_type_camel = hub.tool.gcp.case.camel(RESOURCE_TYPE_FULL.split(".")[-1])
+
+    if hub.tool.gcp.resource_prop_utils.properties_mismatch_resource_id(
+        RESOURCE_TYPE_SIMPLE, resource_id, {**locals(), resource_type_camel: name}
+    ):
+        result["comment"].append(
+            hub.tool.gcp.comment_utils.properties_mismatch_resource_id_comment(
+                RESOURCE_TYPE_FULL, name
+            )
+        )
     if resource_id:
         old_get_ret = await hub.exec.gcp.storage.bucket.get(
             ctx, resource_id=resource_id, projection="full", user_project=user_project
@@ -444,7 +454,9 @@ async def present(
                         RESOURCE_TYPE_FULL, name
                     )
                 )
-                result["new_state"] = {**old, **plan_state}
+                result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                    {**old, **plan_state}
+                )
             else:
                 # Perform update
                 update_ret = await hub.exec.gcp_api.client.storage.bucket.patch(
@@ -495,7 +507,9 @@ async def present(
                 RESOURCE_TYPE_SIMPLE,
                 convert_to_present=True,
             )
-            result["new_state"] = plan_state
+            result["new_state"] = hub.tool.gcp.sanitizers.sanitize_resource_urls(
+                plan_state
+            )
 
             if not if_metageneration_match:
                 if_metageneration_match = "mock_value"
