@@ -1,3 +1,5 @@
+import builtins
+import keyword
 import re
 
 
@@ -38,5 +40,22 @@ def snake(hub, string: str) -> str:
     return string
 
 
+def sanitize_key(hub, key: str) -> str:
+    return hub.tool.gcp.case.unclash(hub.tool.gcp.case.snake(key))
+
+
 def is_snake_case(hub, value: str) -> bool:
     return hub.tool.gcp.case.snake(value) == value
+
+
+def is_unclashed(hub, value: str) -> bool:
+    return hub.tool.gcp.case.unclash(value) == value
+
+
+def unclash(hub, string: str) -> str:
+    """
+    If the string name clashes with a builtin, then append an underscore
+    """
+    if keyword.iskeyword(string) or string in dir(builtins):
+        return f"{string}_"
+    return string
