@@ -103,3 +103,12 @@ def ill_formed_resource_id_comment(
 
 def resource_not_found_comment(hub, resource_type: str, resource_id: str) -> str:
     return f"Resource {resource_type} with resource ID '{resource_id}' not found"
+
+
+def properties_mismatch_resource_id_comment(
+    hub, resource_type: str, name: str = None
+) -> str:
+    hub.log.warning(
+        f"Property values mismatch resource_id for resource type {resource_type} with name {name}."
+    )
+    return f"WARNING: Property values mismatch resource_id for resource type {resource_type} with name {name}."
