@@ -13,4 +13,7 @@ async def should_operate(hub, execution_context: ExecutionContext) -> bool:
 
 async def operate(hub, execution_context: ExecutionContext) -> None:
     response = execution_context.response
-    execution_context.response = {**response, "ret": response.get("ret").get("items")}
+    execution_context.response = {
+        **response,
+        "ret": response.get("ret").get("items", []),
+    }
