@@ -22,6 +22,7 @@ from inspect import signature
 from typing import Dict
 from typing import List
 from typing import Optional
+from typing import Tuple
 
 from pop.loader import LoadedMod
 
@@ -183,6 +184,7 @@ class ContractMod(LoadedMod):
                 return result
 
             if not response:
+                result["ret"] = response
                 return result
 
             if "#operation" in response.get("kind", ""):
@@ -282,9 +284,11 @@ class CompositeContractMod(LoadedMod):
         if self.should_aggregate_results():
             mods_to_call.extend(self._mods)
         else:
-            mod = self.find_best_matching_mod(**kwargs)
+            mod, err = self.find_best_matching_mod(**kwargs)
             if mod:
                 mods_to_call.append(mod)
+            elif err:
+                result["comment"].append(err)
 
         for mod in mods_to_call:
             result_from_mod = await mod(ctx, *args, **kwargs)
@@ -303,7 +307,9 @@ class CompositeContractMod(LoadedMod):
 
         return result
 
-    def find_best_matching_mod(self, **kwargs) -> Optional[ContractMod]:
+    def find_best_matching_mod(
+        self, **kwargs
+    ) -> Tuple[Optional[ContractMod], Optional[str]]:
         resource_paths = self._hub.tool.gcp.resource_prop_utils.get_resource_paths(
             self._resource_type
         )
@@ -322,18 +328,18 @@ class CompositeContractMod(LoadedMod):
                 multiple_max_scores = True
 
         if multiple_max_scores:
-            msg = f"Multiple resource paths of {self._resource_type} match the input arguments."
+            msg = f"Multiple resource paths of {self._resource_type} match the input arguments fully or partially."
             self._hub.log.error(msg)
-            return None
+            return None, msg
 
         if not result:
             msg = (
                 f"No resource paths of {self._resource_type} match the input arguments."
             )
             self._hub.log.warning(msg)
-            return None
+            return None, msg
 
-        return result
+        return result, None
 
     def compute_matching_score(self, resource_path: str, **kwargs) -> int:
         score = 0
@@ -390,7 +396,7 @@ def process_response(hub, response: Dict, resource_type: str, method_name: str)
     else:
         # Multiple entries in call result, e.g. after list() call
         ret_items = []
-        for service_resource in response.get("items") or {}:
+        for service_resource in response.get("items") or []:
             hub.tool.gcp.resource_prop_utils.populate_resource_with_assumed_values(
                 service_resource, resource_type
             )
