@@ -510,3 +510,34 @@ def get_readonly_return_props(
         )
 
     return raw_props
+
+
+def properties_mismatch_resource_id(
+    hub, service_resource_type, resource_id, state_properties
+) -> bool:
+    constructed_resource_id = hub.tool.gcp.resource_prop_utils.construct_resource_id(
+        service_resource_type, state_properties
+    )
+    # This check is needed if properties or resource_id are not supplied
+    if not constructed_resource_id or not resource_id:
+        return False
+    if resource_id != constructed_resource_id:
+        return True
+    return False
+
+
+# TODO: Figure out a generic way to get the native resource path
+def get_service_resource_type(hub, state_resource_path: str) -> str:
+    service_resource_path = state_resource_path.replace("gcp.", "")
+    if "cloudkms" not in service_resource_path:
+        return service_resource_path
+
+    cloudkms_native_resource_paths_dict = {
+        "cloudkms.location": "cloudkms.projects.locations",
+        "cloudkms.key_ring": "cloudkms.projects.locations.key_rings",
+        "cloudkms.import_job": "cloudkms.projects.locations.key_rings.import_jobs",
+        "cloudkms.crypto_key": "cloudkms.projects.locations.key_rings.crypto_keys",
+        "cloudkms.crypto_key_version": "cloudkms.projects.locations.key_rings.crypto_keys.crypto_key_versions",
+    }
+
+    return cloudkms_native_resource_paths_dict[service_resource_path]
