@@ -10,6 +10,7 @@ from typing import Any
 from typing import Dict
 from typing import List
 
+import dict_tools.differ as differ
 from deepdiff import DeepDiff
 from dict_tools.data import NamespaceDict
 
@@ -212,6 +213,8 @@ def compare_states(
         else []
     )
 
+    old_state = hub.tool.gcp.sanitizers.sanitize_resource_urls(old_state)
+    plan_state = hub.tool.gcp.sanitizers.sanitize_resource_urls(plan_state)
     if (old_state is None or plan_state is None) and old_state != plan_state:
         return DeepDiff(
             old_state,
@@ -258,6 +261,55 @@ def compare_states(
     return changes
 
 
+def _clean_state_from_excluded_paths(hub, state, exclude_paths):
+    cleaned_state = state if state else dict()
+    for exclude_path in exclude_paths:
+        path_elements = exclude_path.split(".")
+        _pop_nested_key_from_dict(cleaned_state, path_elements)
+    return cleaned_state
+
+
+def _pop_nested_key_from_dict(state, key_path):
+    if not key_path:
+        return
+
+    if not state or not isinstance(state, dict):
+        return
+
+    root_path_segment = key_path[0]
+
+    if len(key_path) == 1:
+        state.pop(root_path_segment, None)
+        return
+
+    if root_path_segment.endswith("[]"):
+        root_path_segment = root_path_segment[:-2]
+        lst = state.get(root_path_segment, [])
+        if not isinstance(lst, list):
+            return
+        for element in lst:
+            _pop_nested_key_from_dict(element, key_path[1:])
+    else:
+        nested_obj = state.get(root_path_segment, {})
+        _pop_nested_key_from_dict(nested_obj, key_path[1:])
+
+
+def compare_changes(
+    hub,
+    old_state: NamespaceDict,
+    new_state: NamespaceDict,
+    resource_type: str = None,
+) -> Dict:
+    exclude_paths = (
+        hub.tool.gcp.resource_prop_utils.get_exclude_paths(resource_type)
+        if resource_type
+        else []
+    )
+    cleaned_old_state = _clean_state_from_excluded_paths(hub, old_state, exclude_paths)
+    cleaned_new_state = _clean_state_from_excluded_paths(hub, new_state, exclude_paths)
+    return differ.deep_diff(cleaned_old_state, cleaned_new_state)
+
+
 def get_plan_state_value_from_deep_diff_path(hub, deep_diff_path: str, plan_state):
     result = plan_state
     # remove root prefix
